@@ -329,15 +329,15 @@ pub struct ClassicELBHealthCheck {
 }
 
 /// ClassicELBAttributes defines extra attributes associated with a classic load balancer.
-#[serde_as]
+// #[serde_as]
 #[skip_serializing_none]
 #[derive(Clone, Debug, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct ClassicELBAttributes {
     /// IdleTimeout is time that the connection is allowed to be idle (no data
     /// has been sent over the connection) before it is closed by the load balancer.
-    #[serde_as(as = "serde_with::DurationSeconds<i64>")]
-    pub idle_timeout: chrono::Duration, // `json:"idleTimeout,omitempty"`
+    // #[serde_as(as = "serde_with::DurationSeconds<i64>")]
+    pub idle_timeout: Option<i64>, // `json:"idleTimeout,omitempty"`
 
     /// CrossZoneLoadBalancing enables the classic load balancer load balancing.
     // +optional
